%define name      libqglviewer
%define softname  libQGLViewer
%define packname  qglviewer
%define version   2.6.3
%define major     2

%define libname   %mklibname %{packname} %{major}
%define devname   %mklibname %{packname} -d
%define docname   %{name}-doc

Name:		%name
Summary:	Qt based OpenGL generic 3D viewer library
Group:		System/Libraries
Version:	%{version}
Release:	%mkrel 8
License:	GPLv2 with exceptions or GPLv3 with exceptions
URL:		http://www.libqglviewer.com/
Source0:	http://www.libqglviewer.com/src/%{softname}-%{version}.tar.gz
Patch0:		libQGLViewer-2.6.3-qreal.patch

%description
%{softname} is a C++ library based on Qt that eases the creation of OpenGL
3D viewers. It provides some of the typical 3D viewer functionality, such
as the possibility to move the camera using the mouse, which lacks in most
of the other APIs. Other features include mouse manipulated frames,
interpolated keyFrames, object selection, stereo display, screenshot saving
and much more. It can be used by OpenGL beginners as well as to create
complex applications, being fully customizable and easy to extend.

#------------------------------------------------------------------------------

%package -n 	%{libname}
Summary:	Qt based OpenGL generic 3D viewer library
Group:		System/Libraries
BuildRequires:	libqt4-devel
Obsoletes:	libQGLViewer < 2.5.3

%description -n	%{libname}
%{softname} is a C++ library based on Qt that eases the creation of OpenGL
3D viewers. It provides some of the typical 3D viewer functionality, such
as the possibility to move the camera using the mouse, which lacks in most
of the other APIs. Other features include mouse manipulated frames,
interpolated keyFrames, object selection, stereo display, screenshot saving
and much more. It can be used by OpenGL beginners as well as to create
complex applications, being fully customizable and easy to extend.

%files	-n	%{libname}
%doc README LICENCE CHANGELOG GPL_EXCEPTION
%{_libdir}/libQGLViewer.so.%{major}
%{_libdir}/libQGLViewer.so.%{major}.*

#------------------------------------------------------------------------------

%package -n	%{devname}
Summary:	Development files for %{softname}
Group:		Development/KDE and Qt 
Requires:	%{libname} = %{version}-%{release}
Provides:	%{packname}-devel = %{version}-%{release}
Provides:	lib%{packname}-devel = %{version}-%{release}
Obsoletes:	libQGLViewer-devel < 2.5.3

%description -n	%{devname}
The %{devname} package contains libraries and header files for
developing applications that use %{softname}.

%files	-n	%{devname}
%{_includedir}/QGLViewer/
%{_libdir}/libQGLViewer.so
%{_libdir}/qt4/plugins/designer/libqglviewerplugin.so

#------------------------------------------------------------------------------

%package -n	%{docname}
Summary:	API documentation for %{softname}
Group:		Development/KDE and Qt
Requires:	%{packname}-devel >= %{version}-%{release}
BuildArch:	noarch
Obsoletes:	libQGLViewer-doc < 2.5.3

%description -n	%{docname}
API documentation for %{softname}.

%files -n	%{docname}
%doc doc

#------------------------------------------------------------------------------
### Qt5 ###

%define libname_qt5 %mklibname %{packname}-qt5_ %{major}
%define devname_qt5 %mklibname %{packname}-qt5 -d

%package -n	%{libname_qt5}
Summary:        Qt5 based OpenGL generic 3D viewer library
Group:		System/Libraries
BuildRequires:	pkgconfig(Qt5Core)
BuildRequires:	pkgconfig(Qt5Designer)
BuildRequires:	pkgconfig(Qt5Gui)
BuildRequires:	pkgconfig(Qt5OpenGL)
BuildRequires:	pkgconfig(Qt5Widgets)
BuildRequires:	pkgconfig(Qt5Xml)

%description -n	%{libname_qt5}
%{softname} is a C++ library based on Qt5 that eases the creation of OpenGL
3D viewers. It provides some of the typical 3D viewer functionality, such
as the possibility to move the camera using the mouse, which lacks in most
of the other APIs. Other features include mouse manipulated frames,
interpolated keyFrames, object selection, stereo display, screenshot saving
and much more. It can be used by OpenGL beginners as well as to create
complex applications, being fully customizable and easy to extend.

%files	-n	%{libname_qt5}
%doc README LICENCE CHANGELOG GPL_EXCEPTION
%{_libdir}/libQGLViewer-qt5.so.%{major}
%{_libdir}/libQGLViewer-qt5.so.%{major}.*

#------------------------------------------------------------------------------

%package -n	%{devname_qt5}
Summary:	Development files for %{softname}
Group:		Development/KDE and Qt 
Requires:	%{libname_qt5} = %{version}-%{release}
Provides:	%{packname}-qt5-devel = %{version}-%{release}
Provides:	lib%{packname}-qt5-devel = %{version}-%{release}

%description -n	%{devname_qt5}
The %{devname_qt5} package contains libraries and header files for
developing applications that use %{softname}.

%files	-n	%{devname_qt5}
%{_qt5_includedir}/QGLViewer/
%{_libdir}/libQGLViewer-qt5.so
%{_libdir}/libQGLViewer-qt5.prl
%{_qt5_plugindir}/designer/libqglviewerplugin.so

### End Qt5 ###
#------------------------------------------------------------------------------

%prep
%setup -qn %{softname}-%{version}
%autopatch -p1

cp -a . %{_builddir}/qt5

### Prepare Qt5 ###
pushd ../qt5
sed -i -e 's/TARGET = QGLViewer/TARGET = QGLViewer-qt5/' QGLViewer/QGLViewer.pro
sed -i -e 's/-lQGLViewer/-lQGLViewer-qt5/' examples/examples.pri
popd

%build
### Qt4 build ###
pushd QGLViewer
%qmake_qt4 LIB_DIR=%{_libdir} DOC_DIR=%{_docdir} INCLUDE_DIR=%{_includedir}
%make_build
popd

pushd designerPlugin
%qmake_qt4 LIB_DIR=../QGLViewer
%make_build
popd

### Qt5 build ###
pushd ../qt5/QGLViewer
%qmake_qt5 LIB_DIR=%{_libdir} DOC_DIR=%{_docdir} INCLUDE_DIR=%{_qt5_includedir}
%make_build
popd

pushd ../qt5/designerPlugin
%qmake_qt5 LIB_DIR=../QGLViewer
%make_build
popd

%install
### Qt4 install ###
pushd QGLViewer
make -f Makefile -e INSTALL_ROOT=%{buildroot} install_target install_include

rm %{buildroot}%{_libdir}/libQGLViewer.prl
popd

pushd designerPlugin
make -e INSTALL_ROOT=%{buildroot} install
popd

### Qt5 install ###
pushd ../qt5/QGLViewer
make -f Makefile -e INSTALL_ROOT=%{buildroot} install_target install_include
popd

pushd ../qt5/designerPlugin
make -e INSTALL_ROOT=%{buildroot} install
popd


%changelog
* Tue Jul 19 2016 daviddavid <daviddavid> 2.6.3-8.mga6
+ Revision: 1042534
- add the support for Qt5

* Sun Jul 17 2016 pterjan <pterjan> 2.6.3-7.mga6
+ Revision: 1042383
- Add missing changes to the qreal patch

* Sun Jul 17 2016 pterjan <pterjan> 2.6.3-6.mga6
+ Revision: 1042374
- Add back line lost in bad merge

* Sun Jul 17 2016 pterjan <pterjan> 2.6.3-5.mga6
+ Revision: 1042365
- Add fedora patch for qreal != double

  + daviddavid <daviddavid>
    - fix some packages description

* Sun Jul 17 2016 pterjan <pterjan> 2.6.3-4.mga6
+ Revision: 1042313
- Exclude armv7hl too

* Fri Mar 11 2016 pterjan <pterjan> 2.6.3-3.mga6
+ Revision: 988948
- Exclude armv5tl

* Tue Mar 08 2016 blino <blino> 2.6.3-2.mga6
+ Revision: 987266
- rebuild for armv5tl (also missed in first Mga6 mass rebuild)

* Sun Jan 10 2016 filipesaraiva <filipesaraiva> 2.6.3-1.mga6
+ Revision: 921314
- Update to 2.6.3 version;

* Wed Oct 15 2014 umeabot <umeabot> 2.5.3-3.mga5
+ Revision: 743738
- Second Mageia 5 Mass Rebuild

* Tue Sep 23 2014 wally <wally> 2.5.3-2.mga5
+ Revision: 722236
- add general provides to devel pkg
- fix doc pkg requires

* Mon Sep 22 2014 filipesaraiva <filipesaraiva> 2.5.3-1.mga5
+ Revision: 719168
- Renaming SPEC file
- Renaming libqglviewer package to follow Mageia package policy
- SPEC reviewed;
- Add Obsoletes;
- Fix package name to create i586 version correctly
- Add group to metapackage libQGLViewer
- Update to libQGLViewer 2.5.3 version
- SPEC rewrited to provide i586 packages

  + umeabot <umeabot>
    - Mageia 5 Mass Rebuild

* Sun Aug 10 2014 filipesaraiva <filipesaraiva> 2.5.2-1.mga5
+ Revision: 661555
- imported package libQGLViewer

